package com.kafka.demo.producer;

import com.google.gson.Gson;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.producer.Callback;
import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.apache.kafka.clients.producer.RecordMetadata;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.json.GsonJsonParser;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@Slf4j
public class KafkaProducerController {

    @Autowired
    KafkaProducer<String, ItemDetails> kafkaProducer;

    private static final String TOPIC = "topic-1";

    @GetMapping("/writemessage")
    public String writeMessage(){
        //create producer record
        ItemDetails itemDetails = new ItemDetails("shirt", "us polo", 2000);
        //String message = new Gson().toJson(itemDetails).toString();
        ProducerRecord<String, ItemDetails> producerRecord =
                new ProducerRecord<>(TOPIC, itemDetails);

        // send data
        //kafkaProducer.send(producerRecord);

        // kafka produce call back metadata
        kafkaProducer.send(producerRecord, new Callback() {
            @Override
            public void onCompletion(RecordMetadata metadata, Exception exception) {
                if (exception == null){
                    log.info("Record metadata info : \n" +
                            "Topic: "+metadata.topic()+"\n" +
                            "Partition : "+metadata.partition()+"\n" +
                            "Offset : "+ metadata.offset()+"\n" +
                            "Timestamp : "+ metadata.timestamp()
                    );
                }else{
                    log.error("Exception while producing data ",exception);
                }
            }
        });
        kafkaProducer.flush();
        kafkaProducer.close();
        return "write message successfully";
    }
}
